# Genesis Foundation Logger

[![lerna](https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg)](https://lerna.js.org/)
[![TypeScript](https://img.shields.io/badge/%3C%2F%3E-TypeScript-%230074c1.svg)](https://www.typescriptlang.org/)

`foundation-logger` provides a logging utility that currently wraps version 2 of [consola](https://github.com/unjs/consola).

## Installation

To enable this module in your application, follow the steps below.

1. Add `@genesislcap/foundation-logger` as a dependency in your `package.json` file. Whenever you change the dependencies of your project, ensure you run the `$ npm run bootstrap` command again. You can find more information in the [package.json basics](https://learn.genesis.global/secure/web/basics/package-json-basics/) page.

```json
{
  ...
  "dependencies": {
    ...
    "@genesislcap/foundation-logger": "latest"
    ...
  },
  ...
}
```

2. Create a logger in my-package/utils/logger.ts for example.

```ts
import { createLogger } from '@genesislcap/foundation-logger';
export const logger = createLogger('my-package');
```

The logger will be set to `LogLevel.Debug` by default, however you can pass options as the second parameter to tailor this.

```ts
export const logger = createLogger('my-package', { level: LogLevel.Debug, ... });
```

`LoggerOptions` type extends the `ConsolaOptions` type.

3. Use the logger in your package.

```ts
import { logger } from '../utils';
...
logger.debug('Checks complete');
```

4. Explicitly set the log level of an imported foundation package when needed.

```ts
import { logger as commsLogger } from '@genesislcap/foundation-comms';
import { logger as storeLogger } from '@genesislcap/foundation-store';
import { LogLevel } from '@genesislcap/foundation-logger';
commsLogger.level = LogLevel.Warn;
storeLogger.level = LogLevel.Silent;
```

## [API Docs](./docs/api/index.md)

## License

Note: this project provides front-end dependencies and uses licensed components listed in the next section; thus, licenses for those components are required during development. Contact [Genesis Global](https://genesis.global/contact-us/) for more details.

### Licensed components
Genesis low-code platform
